#!/usr/bin/env python
import sys
import numpy
import pylab
import matplotlib.pyplot as plt
import matplotlib

def main():
        
        # --- Get filename
        if (len(sys.argv) < 2):
          print("I need a filename! eg.")
          print("./plot_growth_rates.py file_name.txt")
          return 1
        else:
          filename = str(sys.argv[1])
        
        # --- Parameters
        if ('mast' in filename):
          title  = 'MAST benchmark'
          xlabel = 'mode #'
          ylabel = 'growth-rate [s$^{-1}$]'
          xlog   = 'false'
          rho0 = 0.425e20 * 2 * 1.6726219e-27
        if ('cbm18' in filename):
          title = 'CBM18 ($rho = 10^{19}m^{-3}$)'
          xlabel = 'mode #'
          ylabel = 'growth-rate [s$^{-1}$]'
          xlog   = 'false'
          rho0 = 0.1e20 * 1 * 1.6726219e-27
        if ('inxflow' in filename):
          title = 'X-point benchmark'
          xlabel = 'mode #'
          ylabel = 'growth-rate [s$^{-1}$]'
          xlog   = 'false'
          rho0 = 0.5e20 * 2 * 1.6726219e-27
        if ('kink' in filename):
          title = 'KINK benchmark'
          xlabel = 'resistivity'
          ylabel = 'growth-rate [s$^{-1}$]'
          xlog   = 'true'
          rho0 = 0.1e20 * 1 * 1.6726219e-27
        if ('tear' in filename):
          title = 'TEAR benchmark'
          xlabel = 'resistivity'
          ylabel = 'growth-rate [s$^{-1}$]'
          xlog   = 'true'
          rho0 = 0.1e20 * 1 * 1.6726219e-27

        # --- Normalisation
        mu0  = 1.256637062e-6
        t_norm = (rho0*mu0)**0.5


        # --- Prepare plots
        matplotlib.rcParams.update({'font.size': 24})
        matplotlib.rcParams.update({'font.weight': 'bold'})
        matplotlib.rcParams.update({'legend.fontsize': 18})

        # --- Show plot
        plot_profile(filename, t_norm)
        pylab.xlabel(xlabel)
        pylab.ylabel(ylabel)
        pylab.title(title)
        pylab.legend(['RMHD','FMHD'], loc=2)
        if (xlog == 'true'):
          pylab.xscale("log")
        pylab.yscale("log")
        pylab.show()


def plot_profile(filename, t_norm):
 
        #----Initialise----
        fig = plt.figure()
        ax1 = fig.add_subplot(111)
        file_tmp = open(filename, 'r')
        xxx = numpy.array([])
        yyy1 = numpy.array([])
        yyy2 = numpy.array([])
        for line in file_tmp:
            array_tmp = line.split()
            if (len(array_tmp) == 0): continue
            if (array_tmp[0] == '#'): continue
            xxx  = numpy.append(xxx,  float(array_tmp[0]))
            yyy1 = numpy.append(yyy1, float(array_tmp[1]))
            yyy2 = numpy.append(yyy2, float(array_tmp[2]))
        ax1.plot(xxx,yyy1/t_norm,'sk',linewidth=2,ms=12)
        ax1.plot(xxx,yyy2/t_norm,'vr',linewidth=2,ms=12)
        file_tmp.close()


main()
